"""Visualization tools for Neurogebra."""

from neurogebra.viz.plotting import (
    plot_expression,
    plot_comparison,
    plot_gradient,
    plot_training_history,
)

__all__ = [
    "plot_expression",
    "plot_comparison",
    "plot_gradient",
    "plot_training_history",
]
